function foo () {
	console.log( 'not indented' );
}

export { foo as default };
